@@ -89,9 +89,20 @@ Linux!jef 2006/01/05 21:02:56
 
 void CreateAvancement( GtkWidget * forme )
 {
+	GtkWidget * item;
+
 	Wavancement = create_Avancement();
 	gtk_window_set_transient_for( GTK_WINDOW(Wavancement), GTK_WINDOW(forme) );
 	gtk_widget_show_now( Wavancement );
+/* In case of no mpeg2 support */
+#ifndef HAVE_LIBMPEG2
+	item = lookup_widget(GTK_WIDGET(Wavancement), "mpeg2image" );
+	g_assert( item );
+	gtk_widget_hide( item );
+	item = lookup_widget(GTK_WIDGET(Wavancement), "visumpeg" );
+	g_assert( item );
+	gtk_widget_hide( item );
+#endif
 	gettimeofday( &Progress.Time0, NULL );
 	Progress.totalSteps = 0;
 	Progress.nbSteps = 0;
