@@ -24,6 +24,11 @@ COMMENTAIRE :
 
 #include <gnome.h>
 
+#ifdef __APPLE__
+/* fopen is 64-bit aware on Mac OS X */
+#define fopen64(A,B) fopen(A,B)
+#endif
+
 #define CTEST(x)		/***/
 
 /*
@@ -504,10 +509,16 @@ static char * BuildAudioString( int noPisteVideo, AudioMap_t * audioMap )
 	*audioString = 0;
 	for( i = 0; i < MAX_AUDIO_TRACK; i++ ) {
 		if( audioMap->audioTracks[i] ) {
+			char * lang;
+
 			if( *audioString )	strcat( audioString,"," );
 			strcat( audioString, AudioFormat( noPisteVideo, i ));
 			strcat( audioString, "+" );
-			strcat( audioString, AudioLang( noPisteVideo, i ) );
+			lang = AudioLang( noPisteVideo, i );
+			if( !*lang )
+				strcat( audioString, "nolang" );
+			else
+				strcat( audioString, AudioLang( noPisteVideo, i ) );
 		}
 	}
 	return( strdup( audioString ) );
@@ -852,7 +863,7 @@ int CopyDvd( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap_
 	fsize = FsFree( tmpDir ) - GetWorkBytes();
 	if( fsize < 0 ) {
 		PlayError();
-		MessageBoxError( _("Pas assez de place sur %s\nIl manque %lld octets !"), tmpDir, -fsize );
+		MessageBoxError( _("Pas assez de place sur %s\nIl manque %s octets !"), tmpDir, LLSize2Giga( -fsize ) );
 		return( -1 );
 	}
 /* Verify we have enought free space to run */
@@ -861,7 +872,7 @@ int CopyDvd( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap_
 		if( fsize < 0 ) {
 fprintf(stderr,"FsFree(%lld) GetWantedBytes(%lld)\n", FsFree( isoDir ), GetWantedBytes() );
 			PlayError();
-			MessageBoxError( _("Pas assez de place sur %s\nIl manque %lld octets !"), isoDir, -fsize );
+			MessageBoxError( _("Pas assez de place sur %s\nIl manque %s octets !"), isoDir, LLSize2Giga( -fsize ) );
 			return( -1 );
 		}
 	}
