@@ -193,25 +193,30 @@ int ScanDvd( GtkWidget * forme )
 	GtkTreeIter longest;
 	int noPiste = 0;
 
+	/* Close old data before starting new */
+	DvdClose();
+
 	OpenAnalyse();
-	if( GetDVDTitle( Device, TitreDvd ) < 0 ) {
+
+	if(DvdOpen( Device ) < 0 ) {
+		CloseAnalyse();
+		MessageBoxError( _("Lecture de la structure impossible !") );
+		return( -1 );
+	}
+
+	if( GetDVDTitleUsingLibDVD( TitreDvd ) < 0 ) {
 		CloseAnalyse();
 		MessageBoxError( _("Lecture du titre de %s impossible!"), Device );
 		return( -1 );
 	}
 
+	CloseAnalyse();
+
 	item = lookup_widget(GTK_WIDGET(forme), "titre" );
 	g_assert( item );
 	gtk_entry_set_text( GTK_ENTRY(item), TitreDvd );
 	gtk_widget_show( item );
 
-	DvdClose();
-	if( DvdOpen( Device ) < 0 ) {
-		CloseAnalyse();
-		MessageBoxError( _("Lecture de la structure impossible !") );
-		return( -1 );
-	}
-	CloseAnalyse();
 
 	item = lookup_widget(GTK_WIDGET(forme), "PistesVideo" );
 	g_assert( item );
