@@ -21,6 +21,12 @@ COMMENTAIRE :
 
 #include <gnome.h>
 
+#ifdef __APPLE__
+/* fopen is 64-bit aware on Mac OS X */
+#define fopen64(A,B) fopen(A,B)
+#endif
+
+
 #define __IN_DVDINFO__
 #include "dvdinfo.h"
 
@@ -60,6 +66,32 @@ static struct {
 	{ "zh", "Chinese" }, { "zu", "Zulu" }, { "xx", "Unknown" }, { NULL, "Unknown" }
 };
 
+/***************************************************************************//**
+ *	GETDVDTITLEUSINGLIBDVD-
+ * @date	2008/07/16 22:34:16
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+int GetDVDTitleUsingLibDVD( title )
+char * title;
+{
+	int res;
+
+	res = DVDUDFVolumeInfo( Dvd, title, 33, (unsigned char *) 0, 0);
+/* Provide a default title, in case of DVD directory structure */
+	if( res < 0 ) {
+		strcpy( title, "UNKNOWN" );
+		res = 0;
+	}
+	return( res );
+}
+
 /*------------------------------------------------------------------------------
 	GETTITLE-
 Linux!jef 2005/12/02 22:30:59
@@ -72,12 +104,6 @@ char * title;
 	FILE * fp;
 	int i;
 
-/* fake for tests */
-//	if( strncmp( device, "/dev", 4 ) ) {
-//		strcpy( title,"FAKE_TITLE" );
-//		return( 0 );
-//	}
-
 	fp = fopen64( device, "r" );
 	if( !fp ) {
 		fprintf(stderr,"%s: seek error %d\n", __FUNCTION__, errno );
