@@ -81,7 +81,6 @@ static char * GetCheck( GtkWidget * item )
 	return( "0" );
 }
 
-
 /*------------------------------------------------------------------------------
 	LOADCONFIG-
 Linux!jef 2005/12/02 20:58:39
@@ -92,52 +91,39 @@ int LoadConfig( GtkWidget * propriete )
 	GConfClient * cc;
 	gchar * value;
 	GtkWidget * item;
-	int i;
 
 	cc = gconf_client_get_default();
 	if( !cc )	return( -1 );
 
-	value = gconf_client_get_string( cc, KEY_DEVICE, NULL);
-	if( !value )	value = "/dev/dvd";
 	item = lookup_widget(GTK_WIDGET(propriete), "cfgdev" );
 	g_assert( item );
+	GSList * dvdDevices = getDevices();
 
+	value = gconf_client_get_string( cc, KEY_DEVICE, NULL);
+	/* Use first item from device list if no config set */
+	if( !value ) {
+		if( dvdDevices ) {
+			value = dvdDevices->data;
+		}
+	}
 /* Populate combo */
-	if( FileExist( value ) == 2 ) {
-		gtk_combo_box_append_text( GTK_COMBO_BOX(item), value );
-	}
-	if( FileExist( "/dev/dvd" ) == 2 ) {
-		if( strcmp( value, "/dev/dvd"))	gtk_combo_box_append_text( GTK_COMBO_BOX(item), "/dev/dvd" );
-	}
-/* Ide cdrom/dvdrom devices */
-	for( i = 0; i < 26; i++ ) {
-		char devName[100];
-
-		sprintf( devName, "/dev/hd%c", 'a'+i );
-		if( FileExist( devName ) == 2 ) {
-			if( strcmp( value, devName ))	gtk_combo_box_append_text( GTK_COMBO_BOX(item), devName );
+	int activeItem = -1;
+	int position   = 0;
+	GSList *iterator = dvdDevices;
+	while( iterator ) {
+		// iterate over dvdDevices
+		if( value && strcmp(iterator->data, value) == 0 ) {
+			// prefered device found
+			activeItem = position;
 		}
+		gtk_combo_box_append_text( GTK_COMBO_BOX(item), iterator->data );
+		position++;
+		iterator = iterator->next;
 	}
-/* Scsi cdrom/dvdrom devices */
-	for( i = 0; i < 10; i++ ) {
-		char devName[100];
-
-		sprintf( devName, "/dev/sr%d", i );
-		if( FileExist( devName ) == 2 ) {
-			if( strcmp( value, devName ))	gtk_combo_box_append_text( GTK_COMBO_BOX(item), devName );
-		}
+	freeDevices(dvdDevices);
+	if (activeItem > 0){
+		gtk_combo_box_set_active (  GTK_COMBO_BOX(item), activeItem);
 	}
-/* Loop devices */
-	for( i = 0; i < 10; i++ ) {
-		char devName[100];
-
-		sprintf( devName, "/dev/loop%d", i );
-		if( FileExist( devName ) == 2 && IsLoopDeviceReady( devName ) ) {
-			if( strcmp( value, devName ))	gtk_combo_box_append_text( GTK_COMBO_BOX(item), devName );
-		}
-	}
-
-
 	gtk_entry_set_text( GTK_ENTRY (GTK_BIN (item)->child), value );
 	gtk_widget_show( item );
 
@@ -434,7 +420,7 @@ int VerifConfig( GtkWidget * propriete )
 		MessageBoxError( _("Le repertoire %s n'existe pas !"), isoDir );
 		res = -1;
 	}
-	ret = FileExist( device );
+	ret = IsDvdDevice( device );
 	if( ret != 1 && ret != 2 ) {
 		MessageBoxError( _("Le fichier %s n'existe pas !"), device );
 		res = -1;
