@@ -55,9 +55,6 @@ enum {
 	PHASE2_AVANCER
 };
 
-/* Quand enclaencher l'analyse dymique */
-#define DYNQUAL_PCT		0.01 //	0.10
-
 #ifdef __NEED_GLOBALS__
 GtkWidget * MainDlg;
 int UserStopF = 0;
