@@ -17,12 +17,15 @@ COMMENTAIRE :
 #  include <config.h>
 #endif
 #include <stdio.h>
+#include <signal.h>
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #if defined(__sun)
 #	include <sys/statvfs.h>
 #	include <sys/ioctl.h>
+#elif defined(__APPLE__)
+#   include <sys/mount.h>
 #else
 #	include <sys/statfs.h>
 #endif
@@ -37,6 +40,8 @@ COMMENTAIRE :
 #if defined(__sun)
 #	include <sys/cdio.h>
 #	define NON_BLOCKING
+#elif defined(__APPLE__)
+// TODO: DVD tests not properly implemented yet for Mac OS X
 #else
 #	include <linux/cdrom.h>
 #	include <linux/loop.h>
@@ -45,6 +50,8 @@ COMMENTAIRE :
 
 #include "support.h"
 
+#define CTEST(x)		/* Traces futiles */
+
 char ** environ;
 #define	SH_PATH	"/bin/sh"
 #define	SH_NAME	"sh"
@@ -232,12 +239,33 @@ int FileExist( char * fileName )
 	return( -1 );
 }
 
+/*------------------------------------------------------------------------------
+	IsDvdDevice-
+------------------------------------------------------------------------------*/
+
+int IsDvdDevice( char * fileName )
+{
+	struct stat64 bStat;
+	int res;
+
+	res = stat64( fileName, &bStat );
+// fprintf(stderr,"%s(%s) = %d errno: %d\n", __FUNCTION__,fileName, res, errno );
+	if( res )	return( 0 );
+	if( S_ISREG( bStat.st_mode ) )	return( 1 );
+	if( S_ISBLK( bStat.st_mode ) )	return( 2 );
+#ifdef __APPLE__
+	if ( strncmp("/dev/", fileName, 5) == 0) return 2;
+	return 2;
+#endif
+
+	return( -1 );
+}
 
 /*------------------------------------------------------------------------------
 	MY_POPEN-
 JEF!jef 95/09/26 14:29:09
 	Open a new stream that is a one-way pipe to a
-	child process running the given shell command. 
+	child process running the given shell command.
 ------------------------------------------------------------------------------*/
 FILE * my_popen( command, mode)
 char * command;
@@ -463,15 +491,17 @@ int IsDvdLoaded( char * device )
 	int fd;
 	int ret;
 	struct stat64 b;
-#if !defined(__sun)
+#if !defined(__sun) && !defined(__APPLE__)
 	struct loop_info lInfo;
 #endif
-
 // fprintf(stderr,"%s(%s)\n", __FUNCTION__, device );
 	if( stat64( device, &b) ) {
 // perror( device );
 		return( -1 );
 	}
+/* If this is a VIDEO STRUCTURE go-on */
+	if( S_ISDIR( b.st_mode ) )	return( 1 );
+
 	if( S_ISREG( b.st_mode ) )	return( 1 );
 	fd = open( device, O_RDONLY | O_NONBLOCK);
 	if( fd < 0 ) {
@@ -479,22 +509,25 @@ int IsDvdLoaded( char * device )
 		return( -1 );
 	}
 #if defined (__sun)
-        struct cdrom_tochdr cdth;
-        ret = ioctl( fd, CDROMREADTOCHDR, &cdth);
-        if( cdth.cdth_trk1 > 0 ) {
-#else
-	ret = ioctl( fd,  CDROM_DRIVE_STATUS, CDSL_CURRENT);
-	if( ret == CDS_DISC_OK ) {
-#endif
+	struct cdrom_tochdr cdth;
+	ret = ioctl( fd, CDROMREADTOCHDR, &cdth);
+	if( cdth.cdth_trk1 > 0 ) {
 		close( fd );
 		return( 1 );
 	}
-#if !defined(__sun)
-/* Try to know if it is a loop device */
+#elif defined (__APPLE__)
+	close( fd );
+	return( 1 );
+#else
+	ret = ioctl( fd,  CDROM_DRIVE_STATUS, CDSL_CURRENT);
+	if( ret == CDS_DISC_OK ) {
+		close( fd );
+		return( 1 );
+	}
+	/* Try to know if it is a loop device */
 	ret = ioctl( fd, LOOP_GET_STATUS, &lInfo );
 	close( fd );
 	if( !ret )	return( 1 );
-#else
 	close( fd );
 #endif
 	return( 0 );
@@ -530,7 +563,7 @@ Linux!jef 2007/02/12 20:55:27
 
 int IsLoopDeviceReady( char * loopDevice )
 {
-#if !defined(__sun)
+#if !defined(__sun) && !defined(__APPLE__)
 	struct loop_info lInfo;
 	int fd;
 	int ret;
@@ -545,3 +578,177 @@ int IsLoopDeviceReady( char * loopDevice )
 	return( 0 );
 }
 
+/*------------------------------------------------------------------------------
++	GETDEVICES-
++    get list of available DVD devices as glib single linked list
++------------------------------------------------------------------------------*/
+static GSList * testAndAppend( GSList *list, char *devName )
+{
+	if( FileExist( devName ) == 2 ){
+		char *nameCopy = malloc (strlen(devName)+1);
+		if (nameCopy){
+			strcpy(nameCopy, devName);
+			list = g_slist_append( list, nameCopy);
+			CTEST(fprintf(stderr,"Found device %s\n", nameCopy););
+		}
+	}
+	return( list );
+}
+/***************************************************************************//**
+ *	FREEDEVICES-
+ * @date	2008/07/16 22:41:59
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+void freeDevices( GSList * list )
+{
+	GSList * head = list;
+
+	while( list ) {
+		GSList * next = list->next;
+		if( list->data ) free( list->data );
+		list = next;
+	}
+	g_slist_free( head );
+}
+/***************************************************************************//**
+ *	GETDEVICES-
+ * @date	2008/07/16 22:41:29
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+#ifndef __APPLE__
+GSList *getDevices( void )
+{
+	int i;
+	char devName[100];
+	GSList *list = NULL;
+
+	list = testAndAppend( list, "/dev/dvd" );
+
+/* Ide cdrom/dvdrom devices */
+	for( i = 0; i < 26; i++ ) {
+		sprintf( devName, "/dev/hd%c", 'a'+i );
+		list = testAndAppend( list, devName );
+	}
+/* Scsi cdrom/dvdrom devices */
+	for( i = 0; i < 10; i++ ) {
+		sprintf( devName, "/dev/sr%d", i );
+		list = testAndAppend( list, devName );
+	}
+/* Loop devices */
+	for( i = 0; i < 10; i++ ) {
+		sprintf( devName, "/dev/loop%d", i );
+		if( FileExist( devName ) == 2 && IsLoopDeviceReady( devName ) ) {
+			list = testAndAppend( list, devName );
+		}
+	}
+	return( list );
+}
+#else /* __APPLE__ */
+#include <stdio.h>
+#include <string.h>
+
+#include <paths.h>
+#include <sys/param.h>
+
+#include <IOKit/IOKitLib.h>
+#include <IOKit/IOBSD.h>
+
+char deviceFilePath[MAXPATHLEN]; //MAXPATHLEN is defined in sys/param.h
+
+int getBSDnameForDVDService( io_object_t device, char *path)
+{
+	CFTypeRef deviceNameAsCFString = NULL;
+	Boolean gotString = false;
+	size_t devPathLength;
+
+	/* the DVD drive is the child of the IODVDBlockStorageDriver child */
+	io_iterator_t children;
+	kern_return_t krc = IORegistryEntryGetChildIterator(device, kIOServicePlane, &children);
+	if (krc == KERN_SUCCESS) {
+		io_service_t child;
+		while ((child = IOIteratorNext(children)))
+		{
+			io_string_t type;
+
+			IOObjectGetClass(child, type);
+			if (strcmp( type, "IODVDBlockStorageDriver") == 0){
+				io_service_t drive;
+				IORegistryEntryGetChildEntry(child, kIOServicePlane, &drive);
+				if (child){
+					deviceNameAsCFString = IORegistryEntryCreateCFProperty( drive, CFSTR(kIOBSDNameKey), kCFAllocatorDefault, kNilOptions);
+				}
+			}
+			IOObjectRelease(child);
+		}
+		IOObjectRelease(children);
+	}
+	if (deviceNameAsCFString) {
+		path[0] = '\0';
+		devPathLength = strlen(_PATH_DEV); //_PATH_DEV is defined in paths.h
+		strcpy(path, _PATH_DEV);
+		strcat(path,"r"); // dvds have to be opened in "r"aw mode
+		gotString = CFStringGetCString( deviceNameAsCFString, path + strlen(path), MAXPATHLEN - strlen(deviceFilePath), kCFStringEncodingASCII);
+	}
+	if (gotString) {
+		// printf("Device file path: %s\n", path);
+		//deviceFilePath will look something like /dev/rdisk1
+		return 0;
+	}
+	return -1;
+}
+
+/*
+* Find all DVD drives
+*/
+
+GSList *getDevices(void)
+{
+	GSList *list = NULL;
+
+/*
+* Create a matching dictionary to search for DVD services in the IOKit.
+*/
+	CFMutableDictionaryRef RefMatchingDict = IOServiceMatching("IODVDServices");
+	if (RefMatchingDict == NULL){
+		// no dvd drives found
+		return list;
+	}
+
+/*
+* Get a collection of DVD services.
+*/
+	io_iterator_t DVDServices = 0;
+	IOReturn rc = IOServiceGetMatchingServices(kIOMasterPortDefault, RefMatchingDict, &DVDServices);
+
+	io_object_t DVDService;
+	while ((DVDService = IOIteratorNext(DVDServices)) != 0)
+	{
+		if (getBSDnameForDVDService( DVDService, deviceFilePath ) >= 0){
+			char *nameCopy = malloc (strlen(deviceFilePath)+1);
+			if (nameCopy){
+				strcpy(nameCopy, deviceFilePath);
+				list = g_slist_append( list, nameCopy);
+				CTEST(fprintf(stderr,"Found device %s\n", nameCopy););
+			}
+		}
+		IOObjectRelease(DVDService);
+	}
+	IOObjectRelease(DVDServices);
+
+	return list;
+}
+#endif
