@@ -14,7 +14,7 @@ COMMENTAIRE :
 
 #ifndef __SYSTOOLS_H__
 #define __SYSTOOLS_H__
-/*@$#[systools.c] global proto. AutoProtoSigV1.1. date: 107/02/12 20:56:44 */
+/*@$#[systools.c] global proto. AutoProtoSigV1.1. date: 108/07/16 23:24:46 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
@@ -27,6 +27,7 @@ int flook PROTO((char *fname));
 long long FsFree PROTO((char *fsName));
 int DirExist PROTO((char *dirName));
 int FileExist PROTO((char *fileName));
+int IsDvdDevice PROTO((char *fileName));
 FILE *my_popen PROTO((char *command, char *mode));
 int my_pclose PROTO((FILE *stream));
 char *Duree2String PROTO((int duree));
@@ -36,6 +37,8 @@ int MakeDirIfNeeded PROTO((char *path));
 int IsDvdLoaded PROTO((char *device));
 int StringDuree2Sec PROTO((char *string));
 int IsLoopDeviceReady PROTO((char *loopDevice));
+void freeDevices( GSList * list );
+GSList *getDevices( void );
 #ifdef __cplusplus
 }
 #endif
