@@ -1023,6 +1023,7 @@ vap_phase1 (void)
        !lock (seq_length + SECT_SIZE); seq_length += SECT_SIZE)
   {
     ptr = rptr + seq_length;
+// fprintf(stderr,"VAP_PHASE1: seq_length %d\n", seq_length);
     if( check_pack (ptr) < 0 )	continue;
 
     // avoid duplicate counts for sequence headers
@@ -1032,7 +1033,7 @@ vap_phase1 (void)
     ptr += 14;
     id   = ptr [3];
 
-    //fprintf (stderr, "id=%02x\n", id);
+// fprintf (stderr, "id=%02x\n", id);
 
     switch (id)
     {
@@ -1050,6 +1051,13 @@ vap_phase1 (void)
 	  {
 	    sequence_headers++;
 	    vilen = viptr - vibuf;
+// fprintf(stderr,"vilen=%d\n", vilen );
+/* Weird MPEG2 STREAMS */
+if( !vilen ) {
+	eof = 1;
+
+	return seq_length;
+}
 
 	    return seq_length;
 	  }
@@ -1310,7 +1318,7 @@ static void vaporize( float fact )
 	while( 1 ) {
 // do phase 1 of vaporization
 		seq_length = vap_phase1 ();
-
+// fprintf(stderr,"vap_phase1 := %d vin_bytes= %lld\n", seq_length, vin_bytes );
 		if( eof ) {
 // EOF on source PS
 // process packs after and including last sequence header
